Exception: CodeModels::UnknownNodeType

Inherits:
ParsingError show all
Defined in:
lib/codemodels/parser.rb

Overview

Most CodeModels parser are actually wrapping another parser and adapting it to CodeModels. When they encounter a node type they do not know how to wrap this error is thrown. This is not just for java based parsers, so it should be not moved to codemodels-javaparserwrapper

Instance Attribute Summary

Attributes inherited from ParsingError

#line, #node

Instance Method Summary collapse

Methods inherited from ParsingError

#to_s

Constructor Details

#initialize(node, line = nil, node_type = nil, where = nil) ⇒ UnknownNodeType

Returns a new instance of UnknownNodeType.



67
68
69
# File 'lib/codemodels/parser.rb', line 67

def initialize(node,line=nil,node_type=nil,where=nil)
  super(node,"UnknownNodeType: type=#{node_type} , where: #{where}")
end